@@ -4,7 +4,7 @@ function (object, ...) {
         stop("Use only with 'JMcmprsk' objects.\n")
     out <- object$loglike
     #attr(out, "df") <- nrow(object$Hessian)
-    #attr(out, "nobs") <- object$n
+    attr(out, "nobs") <- object$k
     class(out) <- "logLik"
     out
 }
